/* This file should provide inline versions of string functions.

   Surround GCC-specific parts with #ifdef __GNUC__, and use `__extern_inline'.

   This file should define __STRING_INLINES if functions are actually defined
   as inlines.  */

#ifndef _BITS_STRING_H
#define _BITS_STRING_H	1

/* Define if architecture can access unaligned multi-byte variables.  */
#define _STRING_ARCH_unaligned   0

#endif /* bits/string.h */
